@@ -6,7 +6,7 @@ from os import makedirs, remove
 import json
 import logging
 from pprint import pprint
-import xdg
+from xdg import XDG_DATA_HOME, XDG_CACHE_HOME, XDG_CONFIG_HOME
 from enum import Enum
 
 
@@ -262,15 +262,15 @@ class JsonDatabase(dict):
 
 
 class XDGfolder(Enum):
-    CACHE = xdg.XDG_CACHE_HOME
-    DATA = xdg.XDG_DATA_HOME
-    CONFIG = xdg.XDG_CONFIG_HOME
+    CACHE = XDG_CACHE_HOME
+    DATA = XDG_DATA_HOME
+    CONFIG = XDG_CONFIG_HOME
 
 
 class JsonStorageXDG(JsonStorage):
     """ xdg respectful persistent dicts """
 
-    def __init__(self, name, xdg_folder=xdg.XDG_CACHE_HOME):
+    def __init__(self, name, xdg_folder=XDG_CACHE_HOME):
         self.name = name
         path = join(xdg_folder, "json_database", name + ".json")
         super().__init__(path)
@@ -279,6 +279,6 @@ class JsonStorageXDG(JsonStorage):
 class JsonDatabaseXDG(JsonDatabase):
     """ xdg respectful json database """
 
-    def __init__(self, name, xdg_folder=xdg.XDG_DATA_HOME):
+    def __init__(self, name, xdg_folder=XDG_DATA_HOME):
         path = join(xdg_folder, "json_database", name + ".jsondb")
         super().__init__(name, path)
